Index: docs/ref/contrib/formtools/form-wizard.txt
===================================================================
--- docs/ref/contrib/formtools/form-wizard.txt	(revision 17068)
+++ docs/ref/contrib/formtools/form-wizard.txt	(working copy)
@@ -200,8 +200,8 @@
         {{ wizard.form }}
     {% endif %}
     {% if wizard.steps.prev %}
-    <button name="wizard_prev_step" value="{{ wizard.steps.first }}">{% trans "first step" %}</button>
-    <button name="wizard_prev_step" value="{{ wizard.steps.prev }}">{% trans "prev step" %}</button>
+    <button name="wizard_next_step" value="{{ wizard.steps.first }}">{% trans "first step" %}</button>
+    <button name="wizard_next_step" value="{{ wizard.steps.prev }}">{% trans "prev step" %}</button>
     {% endif %}
     </table>
     <input type="submit">
Index: django/contrib/formtools/tests/wizard/wizardtests/tests.py
===================================================================
--- django/contrib/formtools/tests/wizard/wizardtests/tests.py	(revision 17068)
+++ django/contrib/formtools/tests/wizard/wizardtests/tests.py	(working copy)
@@ -52,7 +52,7 @@
         self.assertEqual(response.context['wizard']['steps'].current, 'form2')
 
         response = self.client.post(self.wizard_url, {
-            'wizard_prev_step': response.context['wizard']['steps'].prev})
+            'wizard_next_step': response.context['wizard']['steps'].prev})
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.context['wizard']['steps'].current, 'form1')
 
Index: django/contrib/formtools/tests/wizard/namedwizardtests/tests.py
===================================================================
--- django/contrib/formtools/tests/wizard/namedwizardtests/tests.py	(revision 17068)
+++ django/contrib/formtools/tests/wizard/namedwizardtests/tests.py	(working copy)
@@ -83,7 +83,7 @@
         response = self.client.post(
             reverse(self.wizard_urlname, kwargs={
                 'step': response.context['wizard']['steps'].current
-            }), {'wizard_prev_step': response.context['wizard']['steps'].prev})
+            }), {'wizard_next_step': response.context['wizard']['steps'].prev})
         response = self.client.get(response['Location'])
 
         self.assertEqual(response.status_code, 200)
Index: django/contrib/formtools/templates/formtools/wizard/wizard_form.html
===================================================================
--- django/contrib/formtools/templates/formtools/wizard/wizard_form.html	(revision 17068)
+++ django/contrib/formtools/templates/formtools/wizard/wizard_form.html	(working copy)
@@ -11,7 +11,7 @@
 {% endif %}
 
 {% if wizard.steps.prev %}
-<button name="wizard_prev_step" value="{{ wizard.steps.first }}">{% trans "first step" %}</button>
-<button name="wizard_prev_step" value="{{ wizard.steps.prev }}">{% trans "prev step" %}</button>
+<button name="wizard_next_step" value="{{ wizard.steps.first }}">{% trans "first step" %}</button>
+<button name="wizard_next_step" value="{{ wizard.steps.prev }}">{% trans "prev step" %}</button>
 {% endif %}
 <input type="submit" name="submit" value="{% trans "submit" %}" />

Index: django/contrib/formtools/wizard/views.py
===================================================================
--- django/contrib/formtools/wizard/views.py	(revision 17068)
+++ django/contrib/formtools/wizard/views.py	(working copy)
@@ -243,12 +243,12 @@
         wasn't successful), the next step (if the current step was stored
         successful) or the done view (if no more steps are available)
         """
         # Look for a wizard_prev_step element in the posted data which
         # contains a valid step name. If one was found, render the requested
-        # form. (This makes stepping back a lot easier).
-        wizard_prev_step = self.request.POST.get('wizard_prev_step', None)
-        if wizard_prev_step and wizard_prev_step in self.get_form_list():
-            self.storage.current_step = wizard_prev_step
+        # form. (This makes stepping back or forard a lot easier).
+        next_step = self.request.POST.get('wizard_next_step', None)
+        if next_step and next_step in self.get_form_list():
+            self.storage.current_step = next_step
             form = self.get_form(
                 data=self.storage.get_step_data(self.steps.current),
                 files=self.storage.get_step_files(self.steps.current))
@@ -638,10 +638,10 @@
         Do a redirect if user presses the prev. step button. The rest of this
         is super'd from FormWizard.
         """
-        prev_step = self.request.POST.get('wizard_prev_step', None)
-        if prev_step and prev_step in self.get_form_list():
-            self.storage.current_step = prev_step
-            return redirect(self.url_name, step=prev_step)
+        next_step = self.request.POST.get('wizard_next_step', None)
+        if next_step and next_step in self.get_form_list():
+            self.storage.current_step = next_step
+            return redirect(self.url_name, step=next_step)
         return super(NamedUrlWizardView, self).post(*args, **kwargs)
 
     def render_next_step(self, form, **kwargs):
@@ -683,4 +683,3 @@
     A NamedUrlFormWizard with pre-configured CookieStorageBackend.
     """
     storage_name = 'django.contrib.formtools.wizard.storage.cookie.CookieStorage'
-
@@ -243,12 +243,12 @@
         successful) or the done view (if no more steps are available)
         """
-        # Look for a wizard_prev_step element in the posted data which
+        # Look for a wizard_next_step element in the posted data which
         # contains a valid step name. If one was found, render the requested